WorldId

Struct WorldId 

pub struct WorldId(/* private fields */);
A unique identifier for a World.

The trait FromWorld is implemented for this type, which returns the ID of the world passed to FromWorld::from_world.

Implementations

Source

impl WorldId

pub fn new() -> Option<Self>

Create a new, unique WorldId. Returns None if the supply of unique WorldIds has been exhausted

Please note that the WorldIds created from this method are unique across time - if a given WorldId is Dropped its value still cannot be reused